pub trait TestRealmExt {
// Required methods
fn loopback_properties(
&self,
) -> impl Future<Output = Result<Option<Properties<AllInterest>>>>;
fn interface_control(&self, id: u64) -> Result<Control>;
}Expand description
Helpers for netemul::TestRealm.
Required Methods
Sourcefn loopback_properties(
&self,
) -> impl Future<Output = Result<Option<Properties<AllInterest>>>>
fn loopback_properties( &self, ) -> impl Future<Output = Result<Option<Properties<AllInterest>>>>
Returns the properties of the loopback interface, or None if there is no
loopback interface.
Sourcefn interface_control(&self, id: u64) -> Result<Control>
fn interface_control(&self, id: u64) -> Result<Control>
Get a fuchsia.net.interfaces.admin/Control client proxy for the
interface identified by [id] via fuchsia.net.root.
Note that one should prefer to operate on a TestInterface if it is
available; but this method exists in order to obtain a Control channel
for interfaces such as loopback.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.